@@ -172,7 +172,17 @@ class Projection(utils.SaveLoad):
         # find rotation that diagonalizes r
         k = numpy.bmat([[numpy.diag(decay * self.s), c * other.s], [matutils.pad(numpy.matrix([]).reshape(0, 0), min(m, n2), n1), r * other.s]])
         logger.debug("computing SVD of %s dense matrix" % str(k.shape))
-        u_k, s_k, _ = numpy.linalg.svd(k, full_matrices = False) # TODO *ugly overkill*!! only need first self.k SVD factors... but there is no LAPACK wrapper for partial svd/eigendecomp in numpy :(
+        try:
+            # in numpy < 1.1.0, running SVD sometimes results in "LinAlgError: SVD did not converge'.
+            # for these early versions of numpy, catch the error and try to compute
+            # SVD again, but over k*k^T.
+            # see http://www.mail-archive.com/numpy-discussion@scipy.org/msg07224.html and
+            # bug ticket http://projects.scipy.org/numpy/ticket/706
+            u_k, s_k, _ = numpy.linalg.svd(k, full_matrices = False) # TODO *ugly overkill*!! only need first self.k SVD factors... but there is no LAPACK wrapper for partial svd/eigendecomp in numpy :(
+        except numpy.linalg.LinAlgError:
+            logging.error("SVD(A) failed; trying SVD(A * A^T)")
+            u_k, s_k, _ = numpy.linalg.svd(numpy.dot(k, k.T), full_matrices = False) # if this fails too, give up
+            s_k = numpy.sqrt(s_k)
         
         k = clipSpectrum(s_k, self.k)
         u_k, s_k = u_k[:, :k], s_k[:k]
